import { useEffect, useRef } from "react";
import { useLink, useMount, useScript } from "../../hook";
import "./index.less";

export interface IVideo {
  fileID: string;
  appID: string;
  psign?: string;
  className?: string;
}

interface IProps {
  video: IVideo | null;
}

/**
 * demo页面：https://tcplayer.vcube.tencent.com/
 *
 * 如果需要在 Chrome 和 Firefox 等现代浏览器中通过 H5 播放 Webrtc 视频, 需要在 tcplayer.vx.x.x.min.js 之前引入 TXLivePlayer-x.x.x.min.js。
 * 有些浏览器环境不支持 Webrtc，播放器会将 Webrtc 流地址自动转换为 HLS 格式地址，因此快直播场景同样需要引入hls.min.x.xx.xm.js。
 * <video objectFill /> fill填满变形，cover等比例会裁剪, contain等比例有黑边
 */
function Player(props: IProps) {
  const playerRef = useRef<any>();

  const initPlayer = (video: IVideo) => {
    const TCPlayer = (window as any).TCPlayer;

    // 重写播放按钮
    const Button = TCPlayer.getComponent("Button");
    const BigPlayButton = TCPlayer.getComponent("BigPlayButton");
    BigPlayButton.prototype.createEl = function () {
      const el = Button.prototype.createEl.call(this);
      const _html =
        '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 1024 1024"><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448s448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372s372 166.6 372 372s-166.6 372-372 372z" fill-opacity=".8" fill="currentColor"></path><path d="M512 140c-205.4 0-372 166.6-372 372s166.6 372 372 372s372-166.6 372-372s-166.6-372-372-372zm164.1 378.2L457.7 677.1a8.02 8.02 0 0 1-12.7-6.5V353a8 8 0 0 1 12.7-6.5l218.4 158.8a7.9 7.9 0 0 1 0 12.9z" fill-opacity=".1" fill="currentColor"></path><path d="M676.1 505.3L457.7 346.5A8 8 0 0 0 445 353v317.6a8.02 8.02 0 0 0 12.7 6.5l218.4-158.9a7.9 7.9 0 0 0 0-12.9z" fill-opacity=".8" fill="currentColor"></path></svg>';
      el.appendChild(
        TCPlayer.dom.createEl("div", {
          className: "vjs-button-icon-custom",
          innerHTML: _html,
        })
      );
      return el;
    };
    playerRef.current = TCPlayer("player_html5_api", video);
  };

  useLink(["/player/tcplayer_pure.min.css"]);
  useScript(
    ["/player/libs/hls.min.0.13.2m.js", "/player/tcplayer.v4.7.2.min.js"],
    () => {
      console.log("执行了", playerRef.current);
      playerRef.current = null;
      if (props.video) initPlayer(props.video);
    }
  );

  return (
    <video
      onContextMenu={(e) => e.preventDefault()}
      id="player_html5_api"
      style={{ width: "100%", height: "100%", objectFit: "contain" }}
      preload="auto"
      playsInline
    ></video>
  );
}

export default Player;
